@@ -99,7 +99,7 @@ class Spark(object):
 
         tableQuery = "select * from {}.{}".format(databaseName, tableName)
 
-        df = evaluate_query(sparkSession, tableQuery)
+        df = self.evaluate_query(tableQuery)
 
         return df
 
@@ -132,7 +132,7 @@ class Spark(object):
 
         countQuery = "select count(1) from (select distinct {} from {}.{})".format(columnName, databaseName, tableName)
     
-        df = self.evaluate_query(sparkSession, countQuery)
+        df = self.evaluate_query(countQuery)
         
         count = self.get_single_row_result(df)
 
