@@ -18,7 +18,7 @@ class FactTestSuite(BaseTestSuite):
         names = loader.getTestCaseNames(FactTestCase)
 
         for name in names:
-            self.TestSuite.addTest(FactTestCase(self.SparkSession, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregation))
+            self.TestSuite.addTest(FactTestCase(self.SparkUtility, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregation))
 
         names = loader.getTestCaseNames(CommonTestCase)
 
